@@ -22,7 +22,7 @@
 #define _MAXIMAEXPRESSION_H
 
 #include "expression.h"
-#include "kdirwatch.h"
+#include "KDirWatch"
 #include <QStringList>
 #include <QXmlStreamReader>
 
@@ -32,7 +32,7 @@ class QTimer;
 
 class MaximaExpression : public Cantor::Expression
 {
-  Q_OBJECT  
+  Q_OBJECT
   public:
     explicit MaximaExpression( Cantor::Session* session);
     ~MaximaExpression();
@@ -44,9 +44,9 @@ class MaximaExpression : public Cantor::Expression
 
     bool needsLatexResult();
 
-    //returns the command that should be send to 
+    //returns the command that should be send to
     //the Maxima process, it's different from the
-    //command() for example to allow plot embedding 
+    //command() for example to allow plot embedding
     QString internalCommand();
 
     //Forces the status of this Expression to done
@@ -56,7 +56,7 @@ class MaximaExpression : public Cantor::Expression
     bool parseOutput(QString& out);
     void parseError(const QString& out);
 
-  private slots:
+  private Q_SLOTS:
     void imageChanged();
 
   private:
@@ -65,7 +65,7 @@ class MaximaExpression : public Cantor::Expression
   private:
     KTemporaryFile *m_tempFile;
     KDirWatch m_fileWatch;
-    bool m_isHelpRequest; 
+    bool m_isHelpRequest;
     bool m_isPlot;
     QTimer* m_askTimer;
     QString m_errorBuffer;
